@@ -70,6 +70,7 @@ KSycocaEntry::Ptr KBuildSycoca::createEntry(KSycocaFactory *currentFactory, cons
     if (!timeStamp) {
         timeStamp = calcResourceHash(m_resourceSubdir, file);
         if (!timeStamp) { // file disappeared meanwhile
+            qCDebug(SYCOCA) << "Couldn't generate timeStamp. Has the file disappeared?";
             return {};
         }
     }
@@ -112,6 +113,7 @@ KSycocaEntry::Ptr KBuildSycoca::createEntry(KSycocaFactory *currentFactory, cons
     if (entry && entry->isValid()) {
         return entry;
     }
+    qCDebug(SYCOCA) << "No valid entry created for" << file;
     return KSycocaEntry::Ptr();
 }
 
@@ -193,7 +195,7 @@ bool KBuildSycoca::build()
         const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, m_resourceSubdir, QStandardPaths::LocateDirectory);
         qCDebug(SYCOCA) << "Looking for subdir" << m_resourceSubdir << "=>" << dirs;
         for (const QString &dir : dirs) {
-            QDirIterator it(dir, QDirIterator::Subdirectories);
+            QDirIterator it(dir, QDirIterator::Subdirectories | QDirIterator::FollowSymlinks);
             while (it.hasNext()) {
                 const QString filePath = it.next();
                 Q_ASSERT(filePath.startsWith(dir)); // due to the line below...
@@ -588,7 +590,7 @@ static quint32 updateHash(const QString &file, quint32 hash)
         // modified timestamp of 0 (UNIX Epoch). In this case, always assume
         // the file as been changed.
         if (timestamp == 0) {
-            static qint64 now = QDateTime::currentDateTimeUtc().toSecsSinceEpoch();
+            static qint64 now = QDateTime::currentSecsSinceEpoch();
             timestamp = now;
         }
         hash += timestamp;
